.. _operators:

Operators
*********

.. automodule:: networkx.operators
.. currentmodule:: networkx

The following operator functions provide standard relabeling and combining operations for networks.

Graph Manipulation
==================

.. autosummary::
   :toctree: generated/

   create_empty_copy
   subgraph 
   cartesian_product
   compose
   complement
   union
   disjoint_union
   intersection
   difference
   symmetric_difference
   line_graph
   ego_graph
   stochastic_graph

Node Relabeling
===============

.. autosummary::
   :toctree: generated/

   convert_node_labels_to_integers
   relabel_nodes

Freezing
========

.. autosummary::
   :toctree: generated/

   freeze
   is_frozen

